#[repr(transparent)]pub struct ExploreServer {
inner: TypedObjectRef<ExploreServer, ()>,
phantom: PhantomData<()>,
}Expand description
A server with an optional third-party network that can be queried to search for public rooms.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<ExploreServer, ()>phantom: PhantomData<()>Implementations
Sourceimpl ExploreServer
impl ExploreServer
Sourcepub fn server_string(&self) -> <PhantomData<Option<String>> as Property>::Value
pub fn server_string(&self) -> <PhantomData<Option<String>> as Property>::Value
The server to query, as a string.
Sourcepub fn third_party_network(
&self,
) -> <OnceCell<Option<String>> as Property>::Value
pub fn third_party_network( &self, ) -> <OnceCell<Option<String>> as Property>::Value
The third-party network to query, if any.
If this is None, the Matrix network will be queried.
Sourcepub fn name(&self) -> <OnceCell<String> as Property>::Value
pub fn name(&self) -> <OnceCell<String> as Property>::Value
The name of the server to display in the list.
Sourcepub fn connect_server_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_server_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the server-string property
Sourcepub fn connect_third_party_network_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_third_party_network_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the third-party-network property
Sourcepub fn connect_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the name property
Sourcepub fn notify_server_string(&self)
pub fn notify_server_string(&self)
Notify listeners of a change in the server-string property
Sourcepub fn notify_third_party_network(&self)
pub fn notify_third_party_network(&self)
Notify listeners of a change in the third-party-network property
Sourcepub fn notify_name(&self)
pub fn notify_name(&self)
Notify listeners of a change in the name property
Sourceimpl ExploreServer
impl ExploreServer
Sourcepub(crate) fn with_default_server(name: &str) -> Self
pub(crate) fn with_default_server(name: &str) -> Self
Construct an ExploreServer for the Matrix network on the default
server.
Sourcepub(crate) fn with_third_party_protocol(
desc: &str,
protocol_id: &str,
instance_id: &str,
) -> Self
pub(crate) fn with_third_party_protocol( desc: &str, protocol_id: &str, instance_id: &str, ) -> Self
Construct an ExploreServer for the given third-party protocol on the
default server.
Sourcepub(crate) fn with_server(server: OwnedServerName) -> Self
pub(crate) fn with_server(server: OwnedServerName) -> Self
Construct an ExploreServer for the Matrix network on the given server.